<?php

/*
 * Reads a simple product map file, and let the user see
 * if a product name is mapped to a combined product name
 */
class ProductMapping {
	
	/**
	 * Comments starts with #
	 * 
	 * Key word is: "MAP: " connected with the combind name e.g. "MAP: Geoframe"
	 * Every line after this keyword, contains of a product name that will be mapped
	 * to this combind name.
	 * 
	 * Product names can use wildcars '?' to match any character or 
	 * '*' to match any substring (0 or more characters).
	 * 
	 */

	
	private $file;
	private $map;
	
	
	public function ProductMapping($filname = null) {
		
		if (is_null($filname)) {
			throw new Exception("We need a product map file..");
		}

		/*if (is_file($filname)) {
			throw new Exception("Could not find map file {$filname}");
		}*/
		
		$this->map = array();
		$this->file = $filname;
		
		$this->load();
	}
	
	private function load() {
		
		if (!file_exists($this->file)) return;
		
		// Parse the mapping file, to an easier format for looking up data..
		$parser = new Parser(file_get_contents($this->file),
			ParserSettings::create(ParserSettings::COMMENT_CHAR, '#')
			->set(ParserSettings::SKIP_COMMENTS, true)
			->set(ParserSettings::SKIP_BLANK_LINES, true)
		);
		
		$product = null;
		
		// For each line we have...
		while ($parser->hasMore()) {
			
			// Get next line
			$line = $parser->next();
			
			// Check if got the keyword
			if (substr(trim($line->toString()), 0, 4) == 'MAP:') {
				$map = $line->next(ParserSettings::create(ParserSettings::SPLIT, ParserSettings::SPLIT_TYPE_SEMI_COLON));				
				$product = trim($map->get(1)->toString());
				$this->map[$product] = array();
				continue;
			}
			
			// if we dont have a product name, we ontinue..
			if (is_null($product)) continue;

			
			// add product name to combined product name
			$this->map[$product][] = trim($line->toString());
		}
		
	}
	
	public function getParent($productName) {		
		foreach ($this->map as $combinedName => $values) {
			foreach ($values as $value) {
				$value = trim(strtolower($value));

				if (eregi($value, $productName)) {
					return $combinedName;
				}
				
				/*
				if (trim(strtolower($productName)) == $value) {
					return $combinedName;
				} else if (trim(strtolower($productName)) == $value) {
					return $combinedName;
				}
				*/
				
			}
		}
		return null;		
	}
	
}

?>